<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2002, Zikula Development Team
 * @link http://www.zikula.org
 * @version $Id: pnadmin.php 296 2009-11-01 20:41:14Z mateo $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package Zikula_System_Modules
 * @subpackage Profile
 * @author Mark West
 */

/**
 * The main administration function
 *
 * @return string HTML string
 */
function Profile_admin_main()
{
    // Security check
    if (!SecurityUtil::checkPermission('Profile::item', '::', ACCESS_EDIT)) {
        return LogUtil::registerPermissionError();
    }

    // Create output object
    $render = & pnRender::getInstance('Profile');

    // Return the output
    return $render->fetch('profile_admin_main.htm');;
}

/**
 * Add new dynamic user data item
 *
 * @author Mark West
 * @return string HTML string
 */
function Profile_admin_new()
{
    // Security check
    if (!SecurityUtil::checkPermission('Profile::item', '::', ACCESS_ADD)) {
        return LogUtil::registerPermissionError();
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // Create output object
    $render = & pnRender::getInstance('Profile', false);

    $render->assign('dtypes',           array(1 => DataUtil::formatForDisplay(__('String', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Text', $dom)),
                                              3 => DataUtil::formatForDisplay(__('Float', $dom)),
                                              4 => DataUtil::formatForDisplay(__('Integer', $dom))));

    $render->assign('displaytypes',     array(0 => DataUtil::formatForDisplay(__('Text box', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Text area', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Checkbox', $dom)),
                                              3 => DataUtil::formatForDisplay(__('Radio button', $dom)),
                                              4 => DataUtil::formatForDisplay(__('Dropdown list', $dom)),
                                              5 => DataUtil::formatForDisplay(__('Calendar', $dom)),
                                              6 => DataUtil::formatForDisplay(__('Date (extended)', $dom)),
                                              7 => DataUtil::formatForDisplay(__('Combo box (text)', $dom))));

    $render->assign('requiredoptions',  array(0 => DataUtil::formatForDisplay(__('No', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Yes', $dom))));

    $render->assign('viewbyoptions',    array(0 => DataUtil::formatForDisplay(__('Everyone', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Registered users only', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Admins only', $dom))));
/*
    $render->assign('adminonlyoptions', array(0 => DataUtil::formatForDisplay(__('No', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Yes', $dom))));
*/
    // Return the output that has been generated by this function
    return $render->fetch('profile_admin_new.htm');
}

/**
 * Function that executes the creation
 *
 * @author Mark West
 * @see Profile_admin_new()
 * @param string 'label' the name of the item to be created
 * @param string 'dtype' the data type of the item to be created
 * @param int 'length' the length of the item to be created if dtype is string
 * @return bool true if item created, false otherwise
 */
function Profile_admin_create($args)
{
    // Get parameters from whatever input we need.
    $label       = FormUtil::getPassedValue('label',       (isset($args['label']) ? $args['label'] : null), 'POST');
    $attrname    = FormUtil::getPassedValue('attributename',(isset($args['attributename']) ? $args['attributename'] : null), 'POST');
    $required    = FormUtil::getPassedValue('required',    (isset($args['required']) ? $args['required'] : null), 'POST');
    $viewby      = FormUtil::getPassedValue('viewby',      (isset($args['viewby']) ? $args['viewby'] : null), 'POST');
    $dtype       = FormUtil::getPassedValue('dtype',       (isset($args['dtype']) ? $args['dtype'] : null), 'POST');
    $length      = FormUtil::getPassedValue('length',      (isset($args['length']) ? $args['length'] : null), 'POST');
    $displaytype = FormUtil::getPassedValue('displaytype', (isset($args['displaytype']) ? $args['displaytype'] : null), 'POST');
    $listoptions = FormUtil::getPassedValue('listoptions', (isset($args['listoptions']) ? $args['listoptions'] : null), 'POST');
    $note        = FormUtil::getPassedValue('note',        (isset($args['note']) ? $args['note'] : null), 'POST');
    $validation  = FormUtil::getPassedValue('validation',  (isset($args['validation']) ? $args['validation'] : null), 'POST');

    // Confirm authorisation code.
    if (!SecurityUtil::confirmAuthKey()) {
        return LogUtil::registerAuthidError(pnModURL('Profile', 'admin', 'view'));
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // Check if empty or already existing...
    if (empty($label)) {
        LogUtil::registerError(__('Error! The property must have an label, such as: _MYINT', $dom));
        return pnRedirect(pnModURL('Profile', 'admin', 'view'));
    }
    if (empty($attrname)) {
        LogUtil::registerError(__('Error! The property must have an internal name, such as: myint', $dom));
        return pnRedirect(pnModURL('Profile', 'admin', 'view'));
    }
    if (pnModAPIFunc('Profile', 'user', 'get', array('proplabel' => $label))) {
        LogUtil::registerError(__('Error! This property label already exists', $dom));
        return pnRedirect(pnModURL('Profile', 'admin', 'view'));
    }
    if (pnModAPIFunc('Profile', 'user', 'get', array('propattribute' => $attrname))) {
        LogUtil::registerError(__('Error! This internal name already exists', $dom));
        return pnRedirect(pnModURL('Profile', 'admin', 'view'));
    }

    // The API function is called.
    $dudid = pnModAPIFunc('Profile', 'admin', 'create',
                          array('label'          => $label,
                                'attribute_name' => $attrname,
                                'required'       => $required,
                                'viewby'         => $viewby,
                                'dtype'          => $dtype,
                                'length'         => $length,
                                'displaytype'    => $displaytype,
                                'listoptions'    => $listoptions,
                                'note'           => $note,
                                'validation'     => $validation));

    // The return value of the function is checked here
    if ($dudid != false) {
        // Success
        LogUtil::registerStatus(__('Done! Account panel property created.', $dom));
    }

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * Modify a dynamic user data item
 * This is a standard function that is called whenever an administrator
 * wishes to modify a current module item
 * @author Mark West
 * @param int 'dudid' the id of the item to be modified
 * @param int 'objectid' generic object id maps to dudid if present
 * @return string HTML string
 */
function Profile_admin_modify($args)
{
    // Get parameters from whatever input we need.
    $dudid 		= (int)FormUtil::getPassedValue('dudid', 	(isset($args['dudid']) ? $args['dudid'] : null), 'GET');
    $objectid 	= (int)FormUtil::getPassedValue('objectid', (isset($args['objectid']) ? $args['objectid'] : null), 'GET');

    // At this stage we check to see if we have been passed $objectid
    if (!empty($objectid)) {
        $dudid = $objectid;
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // The user API function is called.
    $item = pnModAPIFunc('Profile', 'user', 'get', array('propid' => $dudid));

    if ($item == false) {
        return LogUtil::registerError(__('No such account panel property found.', $dom), 404);
    }

    // Security check
    if (!SecurityUtil::checkPermission('Profile::item', "$item[prop_label]::$dudid", ACCESS_EDIT)) {
        return LogUtil::registerPermissionError();
    }

    // Create output object
    $render = & pnRender::getInstance('Profile', false);

    // Add a hidden variable for the item id.
    $render->assign('dudid', $dudid);

    $render->assign('displaytypes',     array(0 => DataUtil::formatForDisplay(__('Text box', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Text area', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Checkbox', $dom)),
                                              3 => DataUtil::formatForDisplay(__('Radio button', $dom)),
                                              4 => DataUtil::formatForDisplay(__('Dropdown list', $dom)),
                                              5 => DataUtil::formatForDisplay(__('Calendar', $dom)),
                                              6 => DataUtil::formatForDisplay(__('Date (extended)', $dom)),
                                              7 => DataUtil::formatForDisplay(__('Combo box (text)', $dom))));

    $render->assign('dtypes',           array(1 => DataUtil::formatForDisplay(__('String', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Text', $dom)),
                                              3 => DataUtil::formatForDisplay(__('Float', $dom)),
                                              4 => DataUtil::formatForDisplay(__('Integer', $dom))));

    $render->assign('requiredoptions',  array(0 => DataUtil::formatForDisplay(__('No', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Yes', $dom))));

    $render->assign('viewbyoptions',    array(0 => DataUtil::formatForDisplay(__('Everyone', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Registered users only', $dom)),
                                              2 => DataUtil::formatForDisplay(__('Admins only', $dom))));
/*
    $render->assign('adminonlyoptions', array(0 => DataUtil::formatForDisplay(__('No', $dom)),
                                              1 => DataUtil::formatForDisplay(__('Yes', $dom))));
*/

    $item['prop_listoptions'] = str_replace("\n", '', $item['prop_listoptions']);

    $render->assign('item', $item);

    // Return the output that has been generated by this function
    return $render->fetch('profile_admin_modify.htm');
}

/**
 * Function that executes the update
 *
 * @author Mark West
 * @see ProfileModify()
 * @param int 'dudid' the id of the item to be updated
 * @param int 'objectid' generic object id maps to dudid if present
 * @param string 'label' the name of the item to be updated
 * @param string 'dtype' the data type of the item
 * @param int 'length' the lenght of item if dtype is string
 * @return bool true if update successful, false otherwise
 */
function Profile_admin_update($args)
{
    // Confirm authorisation code.
    if (!SecurityUtil::confirmAuthKey()) {
        return LogUtil::registerAuthidError(pnModURL('Profile', 'admin', 'view'));
    }

    // Get parameters from whatever input we need.
    $dudid = (int)FormUtil::getPassedValue('dudid', 	   (isset($args['dudid']) ? $args['dudid'] : null), 'POST');
    $objectid = (int)FormUtil::getPassedValue('objectid',  (isset($args['objectid']) ? $args['objectid'] : null), 'POST');
    $label       = FormUtil::getPassedValue('label',       (isset($args['label']) ? $args['label'] : null), 'POST');
    $required    = FormUtil::getPassedValue('required',    (isset($args['required']) ? $args['required'] : null), 'POST');
    $viewby      = FormUtil::getPassedValue('viewby',      (isset($args['viewby']) ? $args['viewby'] : null), 'POST');
    $dtype       = FormUtil::getPassedValue('dtype',       (isset($args['dtype']) ? $args['dtype'] : null), 'POST');
    $length      = FormUtil::getPassedValue('length',      (isset($args['length']) ? $args['length'] : null), 'POST');
    $displaytype = FormUtil::getPassedValue('displaytype', (isset($args['displaytype']) ? $args['displaytype'] : null), 'POST');
    $listoptions = FormUtil::getPassedValue('listoptions', (isset($args['listoptions']) ? $args['listoptions'] : null), 'POST');
    $note        = FormUtil::getPassedValue('note',        (isset($args['note']) ? $args['note'] : null), 'POST');
    $validation  = FormUtil::getPassedValue('validation',  (isset($args['validation']) ? $args['validation'] : null), 'POST');

    // At this stage we check to see if we have been passed $objectid
    if (!empty($objectid)) {
        $dudid = $objectid;
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // The return value of the function is checked here
    if (pnModAPIFunc('Profile', 'admin', 'update',
                    array('dudid'       => $dudid,
                          'required'    => $required,
                          'viewby'      => $viewby,
                          'label'       => $label,
                          'dtype'       => $dtype,
                          'length'      => $length,
                          'displaytype' => $displaytype,
                          'listoptions' => str_replace("\n", "", $listoptions),
                          'note'        => $note,
                          'validation'  => $validation))) {
        // Success
        LogUtil::registerStatus(__('Done! Account panel property updated.', $dom));
    }

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * Increase weight
 *
 * @author Mark West
 * @param  int 'dudid' the id of the item to be updated
 * @return bool true if update successful, false otherwise
 */
function Profile_admin_increase_weight($args)
{
    $dom = ZLanguage::getModuleDomain('Profile');

    $dudid = (int)FormUtil::getPassedValue('dudid', null, 'GET');

    $item = pnModAPIFunc('Profile', 'user', 'get', array('propid' => $dudid));

    if ($item == false) {
        return LogUtil::registerError(__('No such account panel property found.', $dom), 404);
    }

    $new_weight = $item['prop_weight'] + 1;

    // The return value of the function is checked here
    if (pnModAPIFunc('Profile', 'admin', 'update',
                    array('dudid'       => $dudid,
                          'required'    => $item['prop_required'],
                          'viewby'      => $item['prop_viewby'],
                          'label'       => $item['prop_label'],
                          'dtype'       => $item['prop_dtype'],
                          'length'      => $item['prop_length'],
                          'displaytype' => $item['prop_displaytype'],
                          'prop_weight' => $new_weight,
                          'listoptions' => str_replace("\n", '', $item['prop_listoptions']),
                          'note'        => $item['prop_note'],
                          'validation'  => $item['prop_validation']))) {
        // Success
        LogUtil::registerStatus(__('Done! Account panel property updated.', $dom));
    }

    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * Decrease weight
 *
 * @author Mark West
 * @param  int 'dudid' the id of the item to be updated
 * @return bool true if update successful, false otherwise
 */
function Profile_admin_decrease_weight($var)
{
    $dom = ZLanguage::getModuleDomain('Profile');

    $dudid = (int)FormUtil::getPassedValue('dudid', null, 'GET');

    $item = pnModAPIFunc('Profile', 'user', 'get', array('propid' => $dudid));

    if ($item == false) {
        return LogUtil::registerError(__('No such account panel property found.', $dom), 404);
    }

    $new_weight = $item['prop_weight'] - 1;

    // The return value of the function is checked here
    if (pnModAPIFunc('Profile', 'admin', 'update',
                    array('dudid'       => $dudid,
                          'required'    => $item['prop_required'],
                          'viewby'      => $item['prop_viewby'],
                          'label'       => $item['prop_label'],
                          'dtype'       => $item['prop_dtype'],
                          'length'      => $item['prop_length'],
                          'displaytype' => $item['prop_displaytype'],
                          'prop_weight' => $new_weight,
                          'listoptions' => str_replace("\n", '', $item['prop_listoptions']),
                          'note'        => $item['prop_note'],
                          'validation'  => $item['prop_validation']))) {
        // Success
        LogUtil::registerStatus(__('Done! Account panel property updated.', $dom));
    }

    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * delete item
 *
 * @author Mark West
 * @param int 'dudid' the id of the item to be deleted
 * @param int 'objectid' generic object id maps to dudid if present
 * @param bool 'confirmation' confirmation that this item can be deleted
 * @return mixed HTML string if no confirmation, true if delete successful, false otherwise
 */
function Profile_admin_delete($args)
{
    // Get parameters from whatever input we need.
    $dudid        =  (int)FormUtil::getPassedValue('dudid',        (isset($args['dudid']) ? $args['dudid'] : null), 'GETPOST');
    $objectid     =  (int)FormUtil::getPassedValue('objectid',     (isset($args['objectid']) ? $args['objectid'] : null), 'GETPOST');
    $confirmation = (bool)FormUtil::getPassedValue('confirmation', (isset($args['confirmation']) ? $args['confirmation'] : null), 'GETPOST');

    // At this stage we check to see if we have been passed $objectid
    if (!empty($objectid)) {
        $dudid = $objectid;
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // The user API function is called.
    $item = pnModAPIFunc('Profile', 'user', 'get', array('propid' => $dudid));

    if ($item == false) {
        return LogUtil::registerError(__('No such account panel property found.', $dom), 404);
    }

    // Security check
    if (!SecurityUtil::checkPermission('Profile::item', "$item[prop_label]::$dudid", ACCESS_DELETE)) {
        return LogUtil::registerPermissionError();
    }

    // Check for confirmation.
    if (empty($confirmation)) {
        // No confirmation yet - display a suitable form to obtain confirmation
        // of this action from the user

        // Create output object
        $render = & pnRender::getInstance('Profile', false);

        // Add hidden item id to form
        $render->assign('dudid', $dudid);

        // Return the output that has been generated by this function
        return $render->fetch('profile_admin_delete.htm');
    }

    // If we get here it means that the user has confirmed the action

    // Confirm authorisation code.
    if (!SecurityUtil::confirmAuthKey()) {
        return LogUtil::registerAuthidError(pnModURL('Profile', 'admin', 'view'));
    }

    // The API function is called.
    if (pnModAPIFunc('Profile', 'admin', 'delete', array('dudid' => $dudid))) {
        // Success
        LogUtil::registerStatus(__('Done! Account panel property deleted.', $dom));
    }

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * View all items held by this module
 * @author Mark West
 * @return string HTML string
 */
function Profile_admin_view()
{
    // Security check
    if (!SecurityUtil::checkPermission('Profile::', '::', ACCESS_EDIT)) {
        return LogUtil::registerPermissionError();
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // Get parameters from whatever input we need.
    $startnum = (int)FormUtil::getPassedValue('startnum', null, 'GET');

    // The user API function is called.
    $items = pnModAPIFunc('Profile', 'user', 'getall',
                          array('startnum' => $startnum,
                                'numitems' => pnModGetVar('Profile','itemsperpage')));

    $weightlimits = pnModAPIFunc('Profile', 'user', 'getweightlimits');
    $count        = pnModAPIFunc('Profile', 'user', 'countitems');
    $authid       = SecurityUtil::generateAuthKey();

    $x = 1;
    $itmcount = count($items);
    $duditems = array();
    foreach ($items as $item)
    {
        if (SecurityUtil::checkPermission('Profile::', "$item[prop_label]::$item[prop_id]", ACCESS_READ)) {
            // display the proper icom and link to enable or disable the field
            switch (true)
            {
                // Mandatory Images can't be disabled
                case ($item['prop_dtype'] == UDCONST_MANDATORY):
                    $statusval = 1;
                    $status = array('url' => '',
                                    'image' => 'greenled.gif',  'title' => __('Required', $dom));
                    break;

                case ($item['prop_weight'] <> 0):
                    $statusval = 1;
                    $status = array('url'   => pnModURL('Profile', 'admin', 'deactivate',
                                                        array('dudid'    => $item['prop_id'],
                                                              'weight'   => $item['prop_weight'],
                                                              'authid'   => $authid)),
                                    'image' => 'greenled.gif',
                                    'title' => __('Deactivate', $dom));
                    break;

                default:
                    $statusval = 0;
                    $status = array('url'   => pnModURL('Profile','admin','activate',
                                                        array('dudid'    => $item['prop_id'],
                                                              'authid'   => $authid)),
                                    'image' => 'redled.gif',
                                    'title' => __('Activate', $dom));
            }

            switch ($item['prop_dtype'])
            {
                case UDCONST_MANDATORY:
                    $data_type_text = __('Mandatory', $dom);
                    $data_length_text = __('N/A', $dom);
                    break;

                case UDCONST_CORE:
                    $data_type_text = (($item['prop_required'] == 0) ? __('Core', $dom) : __('Core, Required', $dom));
                    $data_length_text = __('N/A', $dom);
                    break;

                case UDCONST_STRING:
                    $data_type_text = (($item['prop_required'] == 0) ? __('String', $dom) : __('String, Required', $dom));
                    if (isset($item['prop_length'])) {
                        $data_length_text = $item['prop_length'];
                    } else {
                        $data_length_text = '0';
                    }
                    break;

                case UDCONST_TEXT:
                    $data_type_text = (($item['prop_required'] == 0) ? __('Text', $dom) : __('Text, Required', $dom));
                    $data_length_text = __('N/A', $dom);
                    break;

                case UDCONST_FLOAT:
                    $data_type_text = (($item['prop_required'] == 0) ? __('Float', $dom) : __('Float, Required', $dom));
                    $data_length_text = __('N/A', $dom);
                    break;

                case UDCONST_INTEGER:
                    $data_type_text = (($item['prop_required'] == 0) ? __('Integer', $dom) : __('Integer, Required', $dom));
                    $data_length_text = __('N/A', $dom);
                    break;

                default:
                    $data_length_text = '';
                    $data_type_text = '';
            }

            // Options for the item.
            $options = array();
            if (SecurityUtil::checkPermission('Profile::', "$item[prop_label]::$item[prop_id]", ACCESS_EDIT)) {
                $options[] = array('url' => pnModURL('Profile', 'admin', 'modify', array('dudid' => $item['prop_id'])),
                                   'image' => 'xedit.gif',
                                   'class' => '',
                                   'title' => __('Edit', $dom));

                if ($item['prop_weight'] > 1) {
                    $options[] = array('url' => pnModURL('Profile', 'admin', 'decrease_weight', array('dudid' => $item['prop_id'])),
                                       'image' => '2uparrow.gif',
                                       'class' => 'profile_up',
                                       'title' => __('Up', $dom));
                }

                if ($x < $itmcount) {
                    $options[] = array('url' => pnModURL('Profile', 'admin', 'increase_weight', array('dudid' => $item['prop_id'])),
                                       'image' => '2downarrow.gif',
                                       'class' => 'profile_down',
                                       'title' => __('Down', $dom));
                }

                if (SecurityUtil::checkPermission('Profile::', "$item[prop_label]::$item[prop_id]", ACCESS_DELETE) && $item['prop_dtype'] > 0) {
                    $options[] = array('url' => pnModURL('Profile', 'admin', 'delete', array('dudid' => $item['prop_id'])),
                                       'image' => '14_layer_deletelayer.gif',
                                       'class' => '',
                                       'title' => __('Delete', $dom));
                }
            }

            $item['status'] = $status;
            $item['statusval'] = $statusval;
            $item['options'] = $options;
            $item['dtype'] = $data_type_text;
            $item['length'] = $data_length_text;
            $duditems[] = $item;
            $x++;
        }
    }

    // Create output object
    $render = & pnRender::getInstance('Profile', false);
    $render->assign('startnum', $startnum);

    $render->assign('duditems', $duditems);

    // assign the values for the smarty plugin to produce a pager in case of there
    // being many items to display.
    $render->assign('pager', array('numitems'     => pnModAPIFunc('Profile', 'user', 'countitems'),
                                   'itemsperpage' => pnModGetVar('Profile', 'itemsperpage')));

    // Return the output that has been generated by this function
    return $render->fetch('profile_admin_view.htm');
}

/**
 * This is a standard function to modify the configuration parameters of the
 * module
 * @author Mark West
 * @return string HTML string
 */
function Profile_admin_modifyconfig()
{
    // Security check
    if (!SecurityUtil::checkPermission('Profile::', '::', ACCESS_ADMIN)) {
        return LogUtil::registerPermissionError();
    }

    // Create output object
    // Appending the module configuration to template
    $render = & pnRender::getInstance('Profile', false, null, true);

    // Return the output that has been generated by this function
    return $render->fetch('profile_admin_modifyconfig.htm');
}

/**
 * Function that updates the module configuration
 *
 * @author Mark West
 * @see Profile_modifyconfig()
 * @param int 'itemsperpage' the number of items to display on each page in admin view
 * @return bool true if update successful, false otherwise
 */
function Profile_admin_updateconfig()
{
    // Security check
    if (!SecurityUtil::checkPermission('Profile::', '::', ACCESS_ADMIN)) {
        return LogUtil::registerPermissionError();
    }

    // Confirm authorisation code.
    if (!SecurityUtil::confirmAuthKey()) {
        return LogUtil::registerAuthidError(pnModURL('Profile', 'admin', 'view'));
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    // Update module variables.
    $itemsperpage = (int)FormUtil::getPassedValue('itemsperpage', 10, 'POST');
    pnModSetVar('Profile', 'itemsperpage', $itemsperpage);

    $itemsperrow = (int)FormUtil::getPassedValue('itemsperrow', 5, 'POST');
    pnModSetVar('Profile', 'itemsperrow',  $itemsperrow);

    $displaygraphics = (bool)FormUtil::getPassedValue('displaygraphics', 0, 'POST');
    pnModSetVar('Profile', 'displaygraphics', $displaygraphics);

    $memberslistitemsperpage = (int)FormUtil::getPassedValue('memberslistitemsperpage', 20, 'POST');
    pnModSetVar('Profile', 'memberslistitemsperpage', $memberslistitemsperpage);

    $onlinemembersitemsperpage = (int)FormUtil::getPassedValue('onlinemembersitemsperpage', 20, 'POST');
    pnModSetVar('Profile', 'onlinemembersitemsperpage', $onlinemembersitemsperpage);

    $recentmembersitemsperpage = (int)FormUtil::getPassedValue('recentmembersitemsperpage', 10, 'POST');
    pnModSetVar('Profile', 'recentmembersitemsperpage', $recentmembersitemsperpage);

    $filterunverified = (bool)FormUtil::getPassedValue('filterunverified', false, 'POST');
    pnModSetVar('Profile', 'filterunverified', $filterunverified);

    $dudtextdisplaytags = (bool)FormUtil::getPassedValue('dudtextdisplaytags', 0, 'POST');
    pnModSetVar('Profile', 'dudtextdisplaytags', $dudtextdisplaytags);

    // Let any other modules know that the modules configuration has been updated
    pnModCallHooks('module', 'updateconfig', 'Profile', array('module' => 'Profile'));

    // the module configuration has been updated successfuly
    LogUtil::registerStatus(__('Done! Module configuration updated.', $dom));

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * Process item activation request
 * @author Mark West
 * @param int 'dudid' id of item activate
 * @return bool true if activation successful, false otherwise
 * @todo remove passing of weight parameter; can be got from API
 */
function Profile_admin_activate($args)
{
    $dom = ZLanguage::getModuleDomain('Profile');

    // Get parameters from whatever input we need.
    $dudid  = (int) FormUtil::getPassedValue('dudid',  (isset($args['dudid']) ? $args['dudid'] : null), 'GET');

    // The API function is called.
    if (pnModAPIFunc('Profile', 'admin', 'activate', array('dudid' => $dudid))) {
        // Success
        LogUtil::registerStatus(__('Done! Item updated.', $dom));
    }

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}

/**
 * Process item deactivation request
 * @author Mark West
 * @param int 'dudid' id of item deactivate
 * @param int 'weight' current weight of item
 * @return bool true if deactivation successful, false otherwise
 * @todo remove passing of weight parameter; can be got from API
 */
function Profile_admin_deactivate($args)
{
    $dom = ZLanguage::getModuleDomain('Profile');

    // Get parameters from whatever input we need.
    $dudid  = (int) FormUtil::getPassedValue('dudid',  (isset($args['dudid']) ? $args['dudid'] : null), 'GET');
    $weight = (int) FormUtil::getPassedValue('weight', (isset($args['weight']) ? $args['weight'] : null), 'GET');

    // Confirm authorisation code.
    if (!SecurityUtil::confirmAuthKey()) {
        return LogUtil::registerAuthidError(pnModURL('Profile', 'admin', 'view'));
    }

    // The API function is called.
    if (pnModAPIFunc('Profile', 'admin', 'deactivate',
                     array('dudid' => $dudid,
                           'weight' => $weight))) {
        // Success
        LogUtil::registerStatus(__('Done! Item updated.', $dom));
    }

    // Let any other modules know that the modules configuration has been updated
    pnModCallHooks('module','updateconfig','Profile', array('module' => 'Profile'));

    // This function generated no output
    return pnRedirect(pnModURL('Profile', 'admin', 'view'));
}
