<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2002, Zikula Development Team
 * @link http://www.zikula.org
 * @version $Id: function.dudoptionalitemmodify.php 296 2009-11-01 20:41:14Z mateo $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * Dynamic User data Module
 *
 * @package      Zikula_System_Modules
 * @subpackage   Profile
 */

/**
 * Smarty function to display an editable dynamic user data field
 *
 * Example
 * <!--[dudoptionalitemmodify proplabel="_YICQ"]-->
 *
 * Example
 * <!--[dudoptionalitemmodify proplabel="_YICQ" uid=$uid]-->
 *
 * Example
 * <!--[dudoptionalitemmodify propattribute="signature"]-->
 *
 * Example
 * <!--[dudoptionalitemmodify item=$item]-->
 *
 * @author       Mark West
 * @since         21/01/04
 * @see            function.exampleadminlinks.php::smarty_function_exampleadminlinks()
 * @param        array       $params            All attributes passed to this function from the template
 * @param        object     &$smarty            Reference to the Smarty object
 * @param        string      $item              The Profile DUD item
 * @param        string      $uid               User ID to display the field value for (-1 = do not load)
 * @param        string      $tableless         Don't use tables to render the markup (optional - default true)
 * @param        string      $class             CSS class to assign to the table row/form row div (optional)
 * @param        string      $proplabel         Property label to display (optional overrides the preformated dud item $item)
 * @param        string      $propattribute     Property attribute to display
 * @param        string      $mode              Display mode: 'normal' = normal editing, 'simple' = simplified for search window
 * @return       string      the results of the module function
 */
function smarty_function_dudoptionalitemmodify($params, &$smarty)
{
    extract($params);
    unset($params);

    if (!pnModAvailable('Profile')) {
        return;
    }

    if (!isset($item)) {
        if (isset($proplabel)) {
            $item = pnModAPIFunc('Profile', 'user', 'get', array('proplabel' => $proplabel));
        } else if (isset($propattribute)) {
            $item = pnModAPIFunc('Profile', 'user', 'get', array('propattribute' => $propattribute));
        } else {
            return;
        }
    }
    if (!isset($item) || empty ($item)) {
        return;
    }

    $dom = ZLanguage::getModuleDomain('Profile');

    if (!isset($uid)) {
        $uid = pnUserGetVar('uid');
    }
    if (!isset($tableless) || !is_bool($tableless)) {
        $tableless = true;
    }
    if (!isset($class) || !is_string($class)) {
        $class = '';
    }
    if (!isset($mode) || empty ($mode)) {
        $mode = 'normal'; // alternative is 'simple'
    }
    if ($mode != 'normal'  &&  $mode != 'simple') {
        return __f('Unknown \'%1$s\' value [%2$s] in duditem', array('mode', $mode), $dom);
    }

    if (isset($item['temp_propdata'])) {
        $uservalue = $item['temp_propdata'];
    } elseif ($uid >= 0) {
        $uservalue = pnUserGetVar($item['prop_attribute_name'], $uid); // ($alias, $uid);
    }

    $render = & pnRender::getInstance('Profile', false, null, true);

    // assign the default values for the control
    $render->assign('tableless',     $tableless);
    $render->assign('class',         $class);
    $render->assign('value',         DataUtil::formatForDisplay($uservalue));
    $render->assign('prop_attribute_name', DataUtil::formatforDisplay($item['prop_attribute_name']));
    $render->assign('proplabeltext', __($item['prop_label'], $dom));
    $render->assign('required',      $item['prop_required']);
    $render->assign('note',          $item['prop_note']);
    $render->assign('mode',          $mode);
    $render->assign('properror',     isset($item['prop_error']) ? $item['prop_error'] : '');
    $render->assign('tempdata',      isset($item['temp_propdata']) ? $item['temp_propdata'] : '');

    // Excluding Timezone of the generics
    if ($item['prop_attribute_name'] == 'tzoffset') {
        if (empty($uservalue)) {
            $uservalue = pnConfigGetVar('timezone_offset');
        }
        $tzinfo = pnModGetVar(PN_CONFIG_MODULE, 'timezone_info');

        $listoutput = array();
        $listoptions = array();
        $selectedvalue = null;
        foreach ($tzinfo as $tzindex => $tzdata) {
            $listoptions[] = $tzindex;
            $listoutput[]  = $tzdata;
            if ($uservalue == $tzindex) {
                 $selectedvalue = $uservalue;
            }
        }

        $render->assign('selectedvalue',  $selectedvalue);
        $render->assign('selectmultiple', '');
        $render->assign('listoptions',    $listoptions);
        $render->assign('listoutput',     $listoutput);
        return $render->fetch('profile_user_dudselect.htm');
    }

    if ($item['prop_attribute_name'] == 'avatar') {
        if (pnModAvailable('Avatar')) {
            if ($item['prop_required']) {
                return $render->fetch('profile_user_dudhidden.htm');
            } else {
                return '';
            }
        }

        if (empty($uservalue)) {
            $uservalue = 'blank.gif';
        }

        $filelist = FileUtil::getFiles('images/avatar', false, true, array('gif', 'jpg', 'png'), 'f');
        asort($filelist);

        $listoutput = $listoptions = $filelist;
        // strip the extension of the output list
        foreach ($listoutput as $k => $output) {
            $listoutput[$k] = substr($output, 0, strrpos($output, '.'));
        }

        $selectedvalue = null;
        if (in_array($uservalue, $filelist)) {
            $selectedvalue = $uservalue;
        }

        $render->assign('selectedvalue',  $selectedvalue);
        $render->assign('selectmultiple', '');
        $render->assign('listoptions',    $listoptions);
        $render->assign('listoutput',     $listoutput);
        return $render->fetch('profile_user_dudselect.htm');
    }

    switch ($item['prop_displaytype'])
    {
        case 0: // TEXT
            $type = 'text';
            break;

        case 1: // TEXTAREA
            if ($mode == 'normal') {
                $type = 'textarea';
            } else {
                $type = 'text';
            }
            break;

        case 2: // CHECKBOX
            $type = 'checkbox';
            break;

        case 3: // RADIO
            $type = 'radio';
            $render->assign('selectedvalue', $uservalue);
            $item['prop_listoptions'] = str_replace(Chr(13), '', str_replace(Chr(13), '', $item['prop_listoptions']));
            $list = array_splice(explode('@@', $item['prop_listoptions']), 1);
            $render->assign('listoptions',   $list);
            $render->assign('listoutput',    $list);
            $render->assign('note',          $item['prop_note']);
            break;

        case 4: // SELECT
            $type = 'select';
            if ($item['multiple'] == 1) {
                $selectmultiple = ' multiple';
            } else {
                $selectmultiple = '';
            }

            $item['prop_listoptions'] = str_replace(Chr(13), '', $item['prop_listoptions']);
            $list = array_splice(explode('@@', $item['prop_listoptions']), 1);

            // Allow list items to be constants
            foreach ($list as $value){
                $listOutput[] =  defined($value) ? constant($value) : $value;
            }

            $render->assign('selectedvalue',  $uservalue);
            $render->assign('selectmultiple', $selectmultiple);
            $render->assign('listoptions',    $list);
            $render->assign('listoutput',     $listOutput);
            break;

        case 5: // DATE
            $type = 'date';
            break;

        case 6: // EXTDATE
            $type = 'extdate';
            $dateArray = explode('-', $uservalue);
            if ($dateArray[0] == '') {
                $dateArray = array(0 => '', 1 => '', 2 => '');
            }
            $render->assign('value', $dateArray);
            break;

        case 7: // COMBOTEXT
            $type = 'combotext';
            $render->assign('value', unserialize($uservalue));

            $first_break  = ';';
            $second_break = ',';

            $first = explode($first_break, $item['prop_validation']);

            for ($k = 0; $k < count($first); $k++) {
                list($id, $val) = explode($second_break, $first[$k]);
                $array[] = array('id'    => $id,
                                 'value' => $val);

            }
            $render->assign('validation', $array);
            break;

        default: // TEXT
            $type = 'text';
            break;
    }

    return $render->fetch('profile_user_dud'.$type.'.htm');
}
