<?php
/**
 * Zikula Application Framework
 *
 * @copyright (c) 2001, Zikula Development Team
 * @link http://www.zikula.org
 * @version $Id: pninit.php 27268 2009-10-30 10:02:50Z mateo $
 * @license GNU/GPL - http://www.gnu.org/copyleft/gpl.html
 * @package Zikula_System_Modules
 * @subpackage AntiCracker
*/

/**
 * initialise the anticracker module
 * This function is only ever called once during the lifetime of a particular
 * module instance
 * @author Mark West
 * @return bool true on success, false otherwise
 */
function securitycenter_init()
{
    // create table
    if (!DBUtil::createTable('sc_anticracker')) {
        return false;
    }

    // create table
    if (!DBUtil::createTable('sc_logevent')) {
        return false;
    }

    // Set up an initial value for a module variable.
    pnModSetVar('SecurityCenter', 'itemsperpage', 10);

    // We use config vars for the rest of the configuration as config vars
    // are available earlier in the PN initialisation process
    pnConfigSetVar('enableanticracker', 1);
    pnConfigSetVar('emailhackattempt', 1);
    pnConfigSetVar('loghackattempttodb', 1);
    pnConfigSetVar('onlysendsummarybyemail', 1);
    pnConfigSetVar('updatecheck', 1);
    pnConfigSetVar('updatefrequency', 7);
    pnConfigSetVar('updatelastchecked', 0);
    pnConfigSetVar('updateversion', PN_VERSION_NUM);
    pnConfigSetVar('keyexpiry', 0);
    pnConfigSetVar('sessionauthkeyua', false);
    pnConfigSetVar('secure_domain', '');
    pnConfigSetVar('signcookies', 1);
    pnConfigSetVar('signingkey', sha1(rand(0, time())));
    pnConfigSetVar('seclevel', 'Medium');
    pnConfigSetVar('secmeddays', 7);
    pnConfigSetVar('secinactivemins', 20);
    pnConfigSetVar('sessionstoretofile', 0);
    pnConfigSetVar('sessionsavepath', '');
    pnConfigSetVar('gc_probability', 100);
    pnConfigSetVar('anonymoussessions', 1);
    pnConfigSetVar('sessionrandregenerate', true);
    pnConfigSetVar('sessionregenerate', true);
    pnConfigSetVar('sessionregeneratefreq', 10);
    pnConfigSetVar('sessionipcheck', 0);
    pnConfigSetVar('sessionname', 'ZSID');

    pnConfigSetVar('filtergetvars', 1);
    pnConfigSetVar('filterpostvars', 1);
    pnConfigSetVar('filtercookievars', 1);
    pnConfigSetVar('outputfilter', 1);

    // now lets set the default mail message contents
    // file is read from pnincludes directory
    $summarycontent = implode('', file(getcwd() . '/system/SecurityCenter/pnincludes/summary.txt'));
    pnConfigSetVar('summarycontent', $summarycontent);
    $fullcontent = implode('', file(getcwd() . '/system/SecurityCenter/pnincludes/full.txt'));
    pnConfigSetVar('fullcontent', $fullcontent);

    // cci vars, see pndocs/ccisecuritystrings.txt
    pnConfigSetVar('usehtaccessbans', 0);
    pnConfigSetVar('extrapostprotection', 0);
    pnConfigSetVar('extragetprotection', 0);
    pnConfigSetVar('checkmultipost', 0);
    pnConfigSetVar('maxmultipost', 4);
    pnConfigSetVar('cpuloadmonitor', 0);
    pnConfigSetVar('cpumaxload', 10.0);
    pnConfigSetVar('ccisessionpath', '');
    pnConfigSetVar('htaccessfilelocation', '.htaccess');
    pnConfigSetVar('nocookiebanthreshold', 10);
    pnConfigSetVar('nocookiewarningthreshold', 2);
    pnConfigSetVar('fastaccessbanthreshold', 40);
    pnConfigSetVar('fastaccesswarnthreshold', 10);
    pnConfigSetVar('javababble', 0);
    pnConfigSetVar('javaencrypt', 0);
    pnConfigSetVar('preservehead', 0);
    pnConfigSetVar('filterarrays', 1);
    pnConfigSetVar('htmlentities', '1');
    pnModSetVar('/PNConfig', 'AllowableHTML', 'a:83:{s:3:"!--";s:1:"2";s:1:"a";s:1:"2";s:4:"abbr";s:1:"0";s:7:"acronym";s:1:"0";s:7:"address";s:1:"0";s:6:"applet";s:1:"0";s:4:"area";s:1:"0";s:1:"b";s:1:"2";s:4:"base";s:1:"0";s:8:"basefont";s:1:"0";s:3:"bdo";s:1:"0";s:3:"big";s:1:"0";s:10:"blockquote";s:1:"2";s:2:"br";s:1:"2";s:6:"button";s:1:"0";s:7:"caption";s:1:"0";s:6:"center";s:1:"2";s:4:"cite";s:1:"0";s:4:"code";s:1:"0";s:3:"col";s:1:"0";s:8:"colgroup";s:1:"0";s:3:"del";s:1:"0";s:3:"dfn";s:1:"0";s:3:"dir";s:1:"0";s:3:"div";s:1:"2";s:2:"dl";s:1:"1";s:2:"dd";s:1:"1";s:2:"dt";s:1:"1";s:2:"em";s:1:"2";s:5:"embed";s:1:"0";s:8:"fieldset";s:1:"0";s:4:"font";i:0;s:4:"form";s:1:"0";s:2:"h1";s:1:"1";s:2:"h2";s:1:"1";s:2:"h3";s:1:"1";s:2:"h4";s:1:"1";s:2:"h5";s:1:"1";s:2:"h6";s:1:"1";s:2:"hr";s:1:"2";s:1:"i";s:1:"2";s:6:"iframe";s:1:"0";s:3:"img";i:0;s:5:"input";s:1:"0";s:3:"ins";s:1:"0";s:3:"kbd";s:1:"0";s:5:"label";s:1:"0";s:6:"legend";s:1:"0";s:2:"li";s:1:"2";s:3:"map";s:1:"0";s:7:"marquee";i:0;s:4:"menu";s:1:"0";s:4:"nobr";s:1:"0";s:6:"object";s:1:"0";s:2:"ol";s:1:"2";s:8:"optgroup";s:1:"0";s:6:"option";s:1:"0";s:1:"p";s:1:"2";s:5:"param";s:1:"0";s:3:"pre";s:1:"2";s:1:"q";s:1:"0";s:1:"s";s:1:"0";s:4:"samp";s:1:"0";s:6:"script";s:1:"0";s:6:"select";s:1:"0";s:5:"small";s:1:"0";s:4:"span";i:0;s:6:"strike";s:1:"0";s:6:"strong";s:1:"2";s:3:"sub";s:1:"0";s:3:"sup";s:1:"0";s:5:"table";s:1:"2";s:5:"tbody";s:1:"0";s:2:"td";s:1:"2";s:8:"textarea";s:1:"0";s:5:"tfoot";s:1:"0";s:2:"th";s:1:"2";s:5:"thead";s:1:"0";s:2:"tr";s:1:"2";s:2:"tt";s:1:"2";s:1:"u";s:1:"0";s:2:"ul";s:1:"2";s:3:"var";s:1:"0";}');

    // Initialisation successful
    return true;
}

/**
 * upgrade the anticracker module from an old version
 * 
 * This function must consider all the released versions of the module!
 * If the upgrade fails at some point, it returns the last upgraded version.
 *
 * @author       Mark West
 * @param        string   $oldVersion   version number string to upgrade from
 * @return       mixed    true on success, last valid version string or false if fails
 */
function securitycenter_upgrade($oldversion)
{
    if (!DBUtil::changeTable('sc_anticracker')) {
        return false;
    }

    if (!DBUtil::changeTable('sc_logevent')) {
        return false;
    }

    switch ($oldversion)
    {
        case '1.3':
            // future upgrade routines
    }

    // Update successful
    return true;
}

/**
 * delete the anticracker module
 * This function is only ever called once during the lifetime of a particular
 * module instance
 * @author Mark West
 * @return bool true on success, false otherwise
 */
function securitycenter_delete()
{
    // Deletion fail - we dont want users disabling this module!
    return false;
}

/**
 * This function deletes obsolete config vars.
 * This will become more important soon (#825)
 * @author Axel Guckelsberger
 */
function _securitycenter_deleteObsoleteConfigVars()
{
    $obsoleteVars = array('zipcompress', 'compresslevel');
    foreach($obsoleteVars as $obVar) {
        pnConfigDelVar($obVar);
    }
}
